==> ph-schematron-5.0.4-sources.jar: org/oclc/purl/dsdl/svrl/ObjectFactory.java <==

package org.oclc.purl.dsdl.svrl;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.oclc.purl.dsdl.svrl package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _SchematronOutput_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "schematron-output");
    public final static QName _Text_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "text");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.oclc.purl.dsdl.svrl
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SchematronOutputType }
     * 
     * @return
     *     The created SchematronOutputType object and never <code>null</code>.
     */
    @Nonnull
    public SchematronOutputType createSchematronOutputType() {
        return new SchematronOutputType();
    }

    /**
     * Create an instance of {@link NsPrefixInAttributeValues }
     * 
     * @return
     *     The created NsPrefixInAttributeValues object and never <code>null</code>.
     */
    @Nonnull
    public NsPrefixInAttributeValues createNsPrefixInAttributeValues() {
        return new NsPrefixInAttributeValues();
    }

    /**
     * Create an instance of {@link ActivePattern }
     * 
     * @return
     *     The created ActivePattern object and never <code>null</code>.
     */
    @Nonnull
    public ActivePattern createActivePattern() {
        return new ActivePattern();
    }

    /**
     * Create an instance of {@link FiredRule }
     * 
     * @return
     *     The created FiredRule object and never <code>null</code>.
     */
    @Nonnull
    public FiredRule createFiredRule() {
        return new FiredRule();
    }

    /**
     * Create an instance of {@link DiagnosticReference }
     * 
     * @return
     *     The created DiagnosticReference object and never <code>null</code>.
     */
    @Nonnull
    public DiagnosticReference createDiagnosticReference() {
        return new DiagnosticReference();
    }

    /**
     * Create an instance of {@link FailedAssert }
     * 
     * @return
     *     The created FailedAssert object and never <code>null</code>.
     */
    @Nonnull
    public FailedAssert createFailedAssert() {
        return new FailedAssert();
    }

    /**
     * Create an instance of {@link SuccessfulReport }
     * 
     * @return
     *     The created SuccessfulReport object and never <code>null</code>.
     */
    @Nonnull
    public SuccessfulReport createSuccessfulReport() {
        return new SuccessfulReport();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "schematron-output")
    @Nonnull
    public JAXBElement<SchematronOutputType> createSchematronOutput(
        @Nullable
        final SchematronOutputType value) {
        return new JAXBElement<SchematronOutputType>(_SchematronOutput_QNAME, SchematronOutputType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     * @return
     *     The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "text")
    @Nonnull
    public JAXBElement<String> createText(
        @Nullable
        final String value) {
        return new JAXBElement<String>(_Text_QNAME, String.class, null, value);
    }

}

==> ph-schematron-5.0.8-sources.jar: org/oclc/purl/dsdl/svrl/ObjectFactory.java <==

package org.oclc.purl.dsdl.svrl;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.oclc.purl.dsdl.svrl package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _SchematronOutput_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "schematron-output");
    public final static QName _Text_QNAME = new QName("http://purl.oclc.org/dsdl/svrl", "text");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.oclc.purl.dsdl.svrl
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link SchematronOutputType }
     * 
     * @return
     *     The created SchematronOutputType object and never <code>null</code>.
     */
    @Nonnull
    public SchematronOutputType createSchematronOutputType() {
        return new SchematronOutputType();
    }

    /**
     * Create an instance of {@link NsPrefixInAttributeValues }
     * 
     * @return
     *     The created NsPrefixInAttributeValues object and never <code>null</code>.
     */
    @Nonnull
    public NsPrefixInAttributeValues createNsPrefixInAttributeValues() {
        return new NsPrefixInAttributeValues();
    }

    /**
     * Create an instance of {@link ActivePattern }
     * 
     * @return
     *     The created ActivePattern object and never <code>null</code>.
     */
    @Nonnull
    public ActivePattern createActivePattern() {
        return new ActivePattern();
    }

    /**
     * Create an instance of {@link FiredRule }
     * 
     * @return
     *     The created FiredRule object and never <code>null</code>.
     */
    @Nonnull
    public FiredRule createFiredRule() {
        return new FiredRule();
    }

    /**
     * Create an instance of {@link DiagnosticReference }
     * 
     * @return
     *     The created DiagnosticReference object and never <code>null</code>.
     */
    @Nonnull
    public DiagnosticReference createDiagnosticReference() {
        return new DiagnosticReference();
    }

    /**
     * Create an instance of {@link FailedAssert }
     * 
     * @return
     *     The created FailedAssert object and never <code>null</code>.
     */
    @Nonnull
    public FailedAssert createFailedAssert() {
        return new FailedAssert();
    }

    /**
     * Create an instance of {@link SuccessfulReport }
     * 
     * @return
     *     The created SuccessfulReport object and never <code>null</code>.
     */
    @Nonnull
    public SuccessfulReport createSuccessfulReport() {
        return new SuccessfulReport();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link SchematronOutputType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "schematron-output")
    @Nonnull
    public JAXBElement<SchematronOutputType> createSchematronOutput(
        @Nullable
        final SchematronOutputType value) {
        return new JAXBElement<SchematronOutputType>(_SchematronOutput_QNAME, SchematronOutputType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "http://purl.oclc.org/dsdl/svrl", name = "text")
    @Nonnull
    public JAXBElement<String> createText(
        @Nullable
        final String value) {
        return new JAXBElement<String>(_Text_QNAME, String.class, null, value);
    }

}
